# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`yp`](#yp): Class for configuring the YP/NIS domain.
* [`yp::bind`](#ypbind): Class for installing and managing `ypbind` daemon.
* [`yp::bind::config`](#ypbindconfig)
* [`yp::bind::install`](#ypbindinstall)
* [`yp::bind::service`](#ypbindservice)
* [`yp::config`](#ypconfig)
* [`yp::ldap`](#ypldap): Class for installing and managing `ypldap` daemon.  This is for OpenBSD only and is the equivalent of PAM/LDAP on Linux.
* [`yp::ldap::config`](#ypldapconfig)
* [`yp::ldap::service`](#ypldapservice)
* [`yp::params`](#ypparams)
* [`yp::serv`](#ypserv): Class for installing and managing `ypserv` daemon.
* [`yp::serv::config`](#ypservconfig)
* [`yp::serv::install`](#ypservinstall)
* [`yp::serv::service`](#ypservservice)

### Defined types

* [`yp::ldap::directory`](#ypldapdirectory): Define an LDAP directory for `ypldap` to poll.
* [`yp::serv::map`](#ypservmap)

### Functions

* [`yp::map_to_make_target`](#ypmap_to_make_target): Transforms a YP map name to the corresponding make target.

### Data types

* [`YP::LDAP::Attribute`](#ypldapattribute)

## Classes

### `yp`

Class for configuring the YP/NIS domain.

* **See also**
  * puppet_classes::yp::bind
    * ::yp::bind
  * puppet_classes::yp::serv
    * ::yp::serv
  * puppet_classes::yp::ldap
    * ::yp::ldap

#### Examples

##### Declaring the class

```puppet
class { '::yp':
  domain => 'example.com',
}
```

#### Parameters

The following parameters are available in the `yp` class.

##### `domain`

Data type: `String`

The YP/NIS domain.

##### `yp_dir`

Data type: `Stdlib::Absolutepath`

The base YP directory, usually `/var/yp`.

Default value: `$::yp::params::yp_dir`

### `yp::bind`

Class for installing and managing `ypbind` daemon.

* **See also**
  * puppet_classes::yp
    * ::yp
  * puppet_classes::yp::serv
    * ::yp::serv
  * puppet_classes::yp::ldap
    * ::yp::ldap

#### Examples

##### Declaring the class

```puppet
include ::portmap

class { '::yp':
  domain => 'example.com',
}

class { '::yp::bind':
  domain  => 'example.com',
  servers => [
    '192.0.2.1',
    '192.0.2.2',
    '192.0.2.3',
  ],
}

Class['::portmap'] ~> Class['::yp::bind'] <~ Class['::yp']

if $::osfamily == 'RedHat' {
  class { '::nsswitch':
    passwd    => ['files', 'nis', 'sss'],
    shadow    => ['files', 'nis', 'sss'],
    group     => ['files', 'nis', 'sss'],
    hosts     => ['files', 'nis', 'dns'],
    netgroup  => ['files', 'nis', 'sss'],
    automount => ['files', 'nis'],
    require   => Class['::yp::bind'],
  }

  pam { 'nis':
    ensure    => present,
    service   => 'system-auth-ac',
    type      => 'password',
    control   => 'sufficient',
    module    => 'pam_unix.so',
    arguments => [
      'md5',
      'shadow',
      'nis',
      'nullok',
      'try_first_pass',
      'use_authtok',
    ],
    require   => Class['::yp::bind'],
  }
}
```

#### Parameters

The following parameters are available in the `yp::bind` class.

##### `domain`

Data type: `String`

The YP/NIS domain.

##### `servers`

Data type: `Optional[Array[Stdlib::IP::Address::NoSubnet, 1]]`

An array of YP servers to use, if left undefined will default
to broadcasting.

Default value: ``undef``

##### `manage_package`

Data type: `Boolean`

Whether to manage a package or not. Some operating
systems have `ypbind` as part of the base system.

Default value: `$::yp::params::bind_manage_package`

##### `package_name`

Data type: `Optional[String]`

The name of the package.

Default value: `$::yp::params::bind_package_name`

##### `service_enable`

Data type: `Boolean`



Default value: `$::yp::params::bind_service_enable`

##### `service_ensure`

Data type: `Enum['running', 'stopped']`



Default value: `$::yp::params::bind_service_ensure`

##### `service_name`

Data type: `String`

The name of the service managing `ypbind`.

Default value: `$::yp::params::bind_service_name`

### `yp::bind::config`

The yp::bind::config class.

### `yp::bind::install`

The yp::bind::install class.

### `yp::bind::service`

The yp::bind::service class.

### `yp::config`

The yp::config class.

### `yp::ldap`

Class for installing and managing `ypldap` daemon.

This is for OpenBSD only and is the equivalent of PAM/LDAP on Linux.

* **See also**
  * puppet_classes::yp
    * ::yp
  * puppet_classes::yp::bind
    * ::yp::bind
  * puppet_classes::yp::serv
    * ::yp::serv
  * puppet_defined_types::yp::ldap::directory
    * ::yp::ldap::directory

#### Examples

##### Declaring the class

```puppet
include ::portmap

class { '::yp::ldap':
  domain      => 'example.com',
  directories => {
    'dc=example,dc=com' => {
      'server'  => '192.0.2.1',
      'bind_dn' => 'cn=ypldap,dc=example,dc=com',
      'bind_pw' => 'secret',
    },
  },
}

class { '::yp':
  domain => 'example.com',
}

class { '::yp::bind':
  domain => 'example.com',
}

Class['::portmap'] ~> Class['::yp::ldap'] ~> Class['::yp::bind'] <~ Class['::yp']
```

#### Parameters

The following parameters are available in the `yp::ldap` class.

##### `domain`

Data type: `String`

The YP/NIS domain for which to provide maps fetched from LDAP.

##### `conf_file`

Data type: `Stdlib::Absolutepath`

The configuration file, usually `/etc/ypldap.conf`.

Default value: `$::yp::params::ldap_conf_file`

##### `directories`

Data type: `Hash[String, Hash[String, Any]]`



Default value: `{}`

##### `interval`

Data type: `Integer[1]`

How often to refresh the maps from LDAP.

Default value: `60`

##### `maps`

Data type: `Array[String, 1]`

The list of YP maps to provide based on LDAP searches.

Default value: `$::yp::params::ldap_maps`

##### `service_enable`

Data type: `Boolean`



Default value: `$::yp::params::ldap_service_enable`

##### `service_ensure`

Data type: `Enum['running', 'stopped']`



Default value: `$::yp::params::ldap_service_ensure`

##### `service_name`

Data type: `String`

The name of the service managing `ypldap`.

Default value: `$::yp::params::ldap_service_name`

##### `tls_cacert_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

### `yp::ldap::config`

The yp::ldap::config class.

### `yp::ldap::service`

The yp::ldap::service class.

### `yp::params`

The yp::params class.

### `yp::serv`

Class for installing and managing `ypserv` daemon.

* **See also**
  * puppet_classes::yp
    * ::yp
  * puppet_classes::yp::bind
    * ::yp::bind
  * puppet_classes::yp::ldap
    * ::yp::ldap

#### Examples

##### Create a master YP server with two additional slaves

```puppet
include ::portmap

class { '::yp':
  domain => 'example.com',
}

class { '::yp::serv':
  domain => 'example.com',
  maps   => [
    'passwd.byname',
    'passwd.byuid',
    'group.bygid',
    'group.byname',
    'netid.byname',
  ],
  slaves => [
    '192.0.2.2',
    '192.0.2.3',
  ],
}

Class['::portmap'] ~> Class['::yp::serv'] <- Class['::yp']
```

##### Create a slave YP server pointing at the above master YP server

```puppet
include ::portmap

class { '::yp':
  domain => 'example.com',
}

class { '::yp::serv':
  domain => 'example.com',
  maps   => [
    'passwd.byname',
    'passwd.byuid',
    'group.bygid',
    'group.byname',
    'netid.byname',
  ],
  master => '192.0.2.1',
}

class { '::yp::bind':
  domain => 'example.com',
}

Class['::portmap'] ~> Class['::yp::serv'] <- Class['::yp']
Class['::yp::serv'] ~> Class['::yp::bind'] <- Class['::yp']
```

#### Parameters

The following parameters are available in the `yp::serv` class.

##### `domain`

Data type: `String`

The YP/NIS domain.

##### `has_yppasswdd`

Data type: `Boolean`

Does this platform provide `yppasswdd` daemon for
changing passwords.

Default value: `$::yp::params::serv_has_yppasswdd`

##### `has_ypxfrd`

Data type: `Boolean`

Does this platform provide a `ypxfrd`  daemon to help map
transfers.

Default value: `$::yp::params::serv_has_ypxfrd`

##### `manage_package`

Data type: `Boolean`

Whether to manage a package or not. Some operating
systems have `ypserv` as part of the base system.

Default value: `$::yp::params::serv_manage_package`

##### `maps`

Data type: `Array[String, 1]`

The YP maps to build. The default is build all supported maps
which often includes some esoteric ones.

Default value: `$::yp::params::serv_maps`

##### `map_extension`

Data type: `Optional[String]`

The file extension added to compiled maps, often `.db`.

Default value: `$::yp::params::serv_map_extension`

##### `master`

Data type: `Optional[Stdlib::IP::Address::NoSubnet]`

If this is a slave YP server, the IP address of the master.

Default value: ``undef``

##### `merge_group`

Data type: `Boolean`

Whether to merge group passwords into the group maps.

Default value: `$::yp::params::serv_merge_group`

##### `merge_passwd`

Data type: `Boolean`

Whether to merge user passwords into the passwd maps, on
some platforms this allows a separate `shadow.byname` map to be created.

Default value: `$::yp::params::serv_merge_passwd`

##### `minimum_gid`

Data type: `Integer[0]`

Any GID lower than this will not be included in the group
maps.

Default value: `$::yp::params::serv_minimum_gid`

##### `minimum_uid`

Data type: `Integer[0]`

Any UID lower than this will not be included in the passwd
maps.

Default value: `$::yp::params::serv_minimum_uid`

##### `package_name`

Data type: `Optional[String]`

The name of the package to install that provides the
`ypserv` daemon.

Default value: `$::yp::params::serv_package_name`

##### `service_enable`

Data type: `Boolean`



Default value: `$::yp::params::serv_service_enable`

##### `service_ensure`

Data type: `Enum['running', 'stopped']`



Default value: `$::yp::params::serv_service_ensure`

##### `yppasswdd_service_name`

Data type: `Optional[String]`

The name of the service managing `yppasswdd`.

Default value: `$::yp::params::serv_yppasswdd_service_name`

##### `ypserv_service_name`

Data type: `String`

The name of the service managing `ypserv`.

Default value: `$::yp::params::serv_ypserv_service_name`

##### `ypxfrd_service_name`

Data type: `Optional[String]`

The name of the service managing `ypxfrd`.

Default value: `$::yp::params::serv_ypxfrd_service_name`

##### `slaves`

Data type: `Optional[Array[Stdlib::IP::Address::NoSubnet, 1]]`

If this is a master YP server, specify the slaves which will be
notified when a map is updated.

Default value: ``undef``

##### `yp_dir`

Data type: `Stdlib::Absolutepath`

The base YP directory, usually `/var/yp`.

Default value: `$::yp::params::yp_dir`

### `yp::serv::config`

The yp::serv::config class.

### `yp::serv::install`

The yp::serv::install class.

### `yp::serv::service`

The yp::serv::service class.

## Defined types

### `yp::ldap::directory`

Define an LDAP directory for `ypldap` to poll.

* **Since** 3.0.0

* **See also**
  * puppet_classes::yp::ldap
    * ::yp::ldap

#### Examples

##### Define a directory

```puppet
::yp::ldap::directory { 'dc=example,dc=com':
  server  => '192.0.2.1',
  bind_dn => 'cn=ypldap,dc=example,dc=com',
  bind_pw => 'secret',
}
```

#### Parameters

The following parameters are available in the `yp::ldap::directory` defined type.

##### `base_dn`

Data type: `Bodgitlib::LDAP::DN`

The base DN from which to perform all LDAP queries.

Default value: `$title`

##### `server`

Data type: `Bodgitlib::Host`

The LDAP server to use.

##### `bind_dn`

Data type: `Optional[Bodgitlib::LDAP::DN]`

The DN to use to bind to the LDAP server.

Default value: ``undef``

##### `bind_pw`

Data type: `Optional[String]`

The password to use when binding to the LDAP server.

Default value: ``undef``

##### `fixed_attributes`

Data type: `Hash[YP::LDAP::Attribute, String]`

A hash of YP map attributes that should not be looked
up from LDAP, but hardcoded to a particular value.

Default value: `{
    'passwd'      => '*',
    'change'      => '0',
    'expire'      => '0',
    'class'       => 'ldap',
    'grouppasswd' => '*',
  }`

##### `group_dn`

Data type: `Optional[Bodgitlib::LDAP::DN]`

The base DN from which to perform group queries, if different
from `base_dn`.

Default value: ``undef``

##### `group_filter`

Data type: `Bodgitlib::LDAP::Filter`

The LDAP search filter to use when searching for groups.

Default value: `'(objectClass=posixGroup)'`

##### `ldap_attributes`

Data type: `Hash[YP::LDAP::Attribute, String]`

A hash of YP map attributes that should be looked up
from regular LDAP attributes.

Default value: `{
    'name'      => 'uid',
    'uid'       => 'uidNumber',
    'gid'       => 'gidNumber',
    'gecos'     => 'cn',
    'home'      => 'homeDirectory',
    'shell'     => 'loginShell',
    'groupname' => 'cn',
    'groupgid'  => 'gidNumber',
  }`

##### `list_attributes`

Data type: `Hash[YP::LDAP::Attribute, String]`

A hash of YP map attributes that should be looked up
from regular LDAP attributes but in the case of multiple values should be
joined together with `,`.

Default value: `{
    'groupmembers' => 'memberUid',
  }`

##### `mode`

Data type: `Optional[Enum['tls', 'ldaps']]`



Default value: ``undef``

##### `port`

Data type: `Optional[Bodgitlib::Port]`



Default value: ``undef``

##### `user_filter`

Data type: `Bodgitlib::LDAP::Filter`

The LDAP search filter to use when searching for users.

Default value: `'(objectClass=posixAccount)'`

### `yp::serv::map`

The yp::serv::map class.

#### Parameters

The following parameters are available in the `yp::serv::map` defined type.

##### `domain`

Data type: `String`



##### `extension`

Data type: `Optional[String]`



##### `master`

Data type: `Optional[Stdlib::IP::Address::NoSubnet]`



##### `yp_dir`

Data type: `Stdlib::Absolutepath`



##### `map`

Data type: `String`



Default value: `$name`

## Functions

### `yp::map_to_make_target`

Type: Puppet Language

Transforms a YP map name to the corresponding make target.

#### Examples

##### 

```puppet
yp::map_to_make_target(['group.byname', 'group.bygid'])
yp::map_to_make_target('passwd.byname')
```

#### `yp::map_to_make_target(Variant[String, Array[String, 1]] $maps)`

Transforms a YP map name to the corresponding make target.

Returns: `Variant[String, Array[String, 1]]` Either a single make target or array of make targets.

##### Examples

###### 

```puppet
yp::map_to_make_target(['group.byname', 'group.bygid'])
yp::map_to_make_target('passwd.byname')
```

##### `maps`

Data type: `Variant[String, Array[String, 1]]`

Either a single map name or an array of map names.

## Data types

### `YP::LDAP::Attribute`

The YP::LDAP::Attribute data type.

* **Since** 2.0.0

Alias of `Enum['change', 'class', 'expire', 'gecos', 'gid', 'groupgid', 'groupmembers', 'groupname', 'grouppasswd', 'home', 'name', 'passwd', 'shell', 'uid']`

